package org.jeecg.modules.system.controller;

import cn.com.ctop.userefficientvideomap.entity.DesignMaterialInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.modules.system.service.IPerformanceService2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 设计师季度绩效表2
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2019-12-10
 */
@Slf4j
@Api(tags = "设计师季度绩效表2")
@RestController
@RequestMapping("/ctop/performance2")
public class PerformanceController2 {
    @Autowired
    private IPerformanceService2 performanceService;

    //平台的总有效数量、素材总数、素材有效率、总跑量、当前可获得绩效
    @AutoLog(value = "平台的总有效数量、素材总数、素材有效率、总跑量、当前可获得绩效")
    @ApiOperation(value = "平台的总有效数量、素材总数、素材有效率、总跑量、当前可获得绩效", notes = "平台的总有效数量、素材总数、素材有效率、总跑量、当前可获得绩效")
    @PostMapping(value = "/getPerformanceInfo")
    public Result<Map<String,Object>> getPerformanceInfo() {
        Result<Map<String, Object>> result = new Result<>();
        Map<String,Object> resultMap = new HashMap<>();
        try {
            resultMap = performanceService.getPerformanceInfo();
            result.setSuccess(true);
            result.setResult(resultMap);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("/getPerformanceInfo出错啦");
        }
        return result;
    }

    //有效率排行榜
    @AutoLog(value = "有效率排行榜")
    @ApiOperation(value = "有效率排行榜", notes = "有效率排行榜")
    @PostMapping(value = "/effiRateRank")
    public Result<Map<String,Object>> effiRateRank(@RequestParam(name = "pageSize")Integer pageSize) {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        Map<String,Object> resultMap = new HashMap<>();
        try {
            resultMap = performanceService.effiRateRank(pageSize);
            result.setSuccess(true);
            result.setResult(resultMap);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("/ctop/performance2/effiRateRank出错啦");
        }
        return result;
    }

    //素材、素材跑量、封面点击数、封面曝光数、行为数
    @AutoLog(value = "素材、素材跑量、封面点击数、封面曝光数、行为数")
    @ApiOperation(value = "素材、素材跑量、封面点击数、封面曝光数、行为数", notes = "素材、素材跑量、封面点击数、封面曝光数、行为数")
    @PostMapping(value = "/materialInfoList")
    public Result<Map<String,Object>> materialInfoList() {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        Map<String,Object> resultMap = new HashMap<>();
        try {
            List<DesignMaterialInfo> designMaterialInfoList= performanceService.materialInfoList();
            resultMap.put("designMaterialInfoList",designMaterialInfoList);
            result.setSuccess(true);
            result.setResult(resultMap);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("/ctop/performance2/materialInfoList出错啦");
        }
        return result;
    }

    //点击+符号 投放账户、投放账户、跑量
    @AutoLog(value = "点击账户增加_投放账户、投放账户、跑量")
    @ApiOperation(value = "点击账户增加_投放账户、投放账户、跑量", notes = "点击账户增加_投放账户、投放账户、跑量")
    @PostMapping(value = "/materialAccountInfo")
    public Result<Map<String,Object>> materialAccountInfo(@RequestParam(name = "materialId")String materialId) {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        Map<String,Object> resultMap = new HashMap<>();
        try {
            List<DesignMaterialInfo> designMaterialInfoList= performanceService.materialAccountInfo(materialId);
            resultMap.put("designMaterialInfoList",designMaterialInfoList);
            result.setSuccess(true);
            result.setResult(resultMap);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("/ctop/performance2/materialAccountInfo出错啦");
        }
        return result;
    }

    @AutoLog(value = "根据year、quarter计算季度设计师绩效")
    @ApiOperation(value = "根据year、quarter计算季度设计师绩效", notes = "根据year、quarter计算季度设计师绩效")
    @PostMapping(value = "/designerPerformance")
    public Result<Map<String,Object>> designerPerformanceTask(@RequestParam(name = "year", required = true) int year,
                                                              @RequestParam(name = "quarter", required = true) int quarter) {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        try {
            performanceService.designerPerformanceTask(year,quarter);
            result.setSuccess(true);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            log.error("/ctop/performance2/designerPerformance出错啦" + "year:" + year + " quarter:" + quarter);
            result.error500("/ctop/performance2/designerPerformance出错啦");
        }
        return result;
    }

    @AutoLog(value = "有效视频定时任务")
    @ApiOperation(value = "有效视频定时任务", notes = "calcDate传递yyyy-MM-dd格式的日期")
    @PostMapping(value = "/efficientVideo")
    public Result<Map<String,Object>> efficientVideo(@RequestParam(name = "calcDate", required = true) String calcDate) {
        log.info("有效视频任务开始，有效视频所属时间为" + calcDate);
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        if (StringUtils.isBlank(calcDate)){
            result.error500("时间不能为空");
        }
        try {
            performanceService.efficientVideoTask(calcDate);
            result.setSuccess(true);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            log.error("/ctop/performance2/efficientVideo出错啦" + "date:" + calcDate );
            result.error500("/ctop/performance2/efficientVideo出错啦");
        }
        return result;
    }

    @AutoLog(value = "根据year、quarter计算kuaishou季度设计师绩效")
    @ApiOperation(value = "根据year、quarter计算kuaishou季度设计师绩效", notes = "根据year、quarter计算kuaishou季度设计师绩效")
    @PostMapping(value = "/toutiaoDesignerPerformance")
    public Result<Map<String,Object>> toutiaoDesignerPerformance(@RequestParam(name = "year", required = true) int year,
                                                              @RequestParam(name = "quarter", required = true) int quarter) {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        try {
            performanceService.toutiaoDesigner(year,quarter);
            result.setSuccess(true);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            log.error("/ctop/performance2/toutiaoDesignerPerformance出错啦" + "year:" + year + " quarter:" + quarter);
            result.error500("/ctop/performance2/toutiaoDesignerPerformance出错啦");
        }
        return result;
    }

    @AutoLog(value = "根据year、quarter计算toutiao季度设计师绩效")
    @ApiOperation(value = "根据year、quarter计算toutiao季度设计师绩效", notes = "根据year、quarter计算toutiao季度设计师绩效")
    @PostMapping(value = "/kuaishouDesignerPerformance")
    public Result<Map<String,Object>> kuaishouDesignerPerformance(@RequestParam(name = "year", required = true) int year,
                                                              @RequestParam(name = "quarter", required = true) int quarter) {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        try {
            performanceService.kuaishouDesigner(year,quarter);
            result.setSuccess(true);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            log.error("/ctop/performance2/kuaishouDesignerPerformance出错啦" + "year:" + year + " quarter:" + quarter);
            result.error500("/ctop/performance2/kuaishouDesignerPerformance出错啦");
        }
        return result;
    }

    @AutoLog(value = "获取设计师组下所有人的绩效")
    @ApiOperation(value = "获取设计师组下所有人的绩效", notes = "获取设计师组下所有人的绩效")
    @PostMapping(value = "/designerLastQuarterPerformanceInfo")
    public Result<Map<String,Object>> designerLastQuarterPerformanceInfo() {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        try {
            Map<String,Object> resultMap = performanceService.designerLastQuarterPerformanceInfo();
            result.setResult(resultMap);
            result.setSuccess(true);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            log.error("/ctop/performance2/designerLastQuarterPerformanceInfo出错啦");
            result.error500("/ctop/performance2/designerLastQuarterPerformanceInfo出错啦");
        }
        return result;
    }

    @AutoLog(value = "获取同一媒体类型下上个季度所有人的绩效")
    @ApiOperation(value = "获取同一媒体类型下上个季度所有人的绩效", notes = "获取同一媒体类型下上个季度所有人的绩效")
    @PostMapping(value = "/quarterUserPerformanceList")
    public Result<Map<String,Object>> quarterUserPerformanceList(@RequestParam(name = "appType", required = true) int appType) {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        try {
            Map<String,Object> resultMap = performanceService.quarterUserPerformanceList(appType);
            result.setResult(resultMap);
            result.setSuccess(true);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            log.error("/ctop/performance2/quarterUserPerformanceList出错啦");
            result.error500("/ctop/performance2/quarterUserPerformanceList出错啦");
        }
        return result;
    }

    @AutoLog(value = "获取快手上个季度的季度有效数、素材总数、上个季度的绩效")
    @ApiOperation(value = "获取快手上个季度的季度有效数、素材总数、上个季度的绩效", notes = "获取快手上个季度的季度有效数、素材总数、上个季度的绩效")
    @PostMapping(value = "/kuaishouDesignerLastQuarterPerformanceInfo")
    public Result<Map<String,Object>> kuaishouDesignerLastQuarterPerformanceInfo() {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        Map<String,Object> resultMap = new HashMap<>();
        try {
            resultMap = performanceService.kuaishouDesignerLastQuarterPerformanceInfo();
            result.setResult(resultMap);
            result.setSuccess(true);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            log.error("/ctop/performance2/kuaishouDesignerLastQuarterPerformanceInfo出错啦");
            result.error500("/ctop/performance2/kuaishouDesignerLastQuarterPerformanceInfo出错啦");
        }
        return result;
    }

    @AutoLog(value = "获取平面设计师上个季度的绩效")
    @ApiOperation(value = "获取平面设计师上个季度的绩效", notes = "获取平面设计师上个季度的绩效")
    @PostMapping(value = "/planeLastQuarterPerformanceInfo")
    public Result<Map<String,Object>> planeLastQuarterPerformanceInfo(@RequestParam(name = "appType", required = true) int appType) {
        Result<Map<String,Object>> result = new Result<Map<String,Object>>();
        try {
            Map<String, Object> resultMap = performanceService.planeLastQuarterPerformanceInfo(appType);
            result.setResult(resultMap);
            result.setSuccess(true);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            log.error("/ctop/performance2/planeLastQuarterPerformanceInfo出错啦");
            result.error500("/ctop/performance2/planeLastQuarterPerformanceInfo出错啦");
        }
        return result;
    }


}
